summaryrefslogtreecommitdiffstats
path: root/drawinglayer
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-15 09:44:47 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-15 09:44:47 +0000
commit91fe6b97952aa6f7cef58327fd085a17db38ad95 (patch)
tree7a4412295bfb80e15a4936fe67d4bd7b96458ce8 /drawinglayer
parentReleasing progress-linux version 4:24.2.1-4~progress7.99u1. (diff)
downloadlibreoffice-91fe6b97952aa6f7cef58327fd085a17db38ad95.tar.xz
libreoffice-91fe6b97952aa6f7cef58327fd085a17db38ad95.zip
Merging upstream version 4:24.2.2.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'drawinglayer')
-rw-r--r--drawinglayer/inc/texture/texture3d.hxx2
-rw-r--r--drawinglayer/source/texture/texture3d.cxx12
2 files changed, 7 insertions, 7 deletions
diff --git a/drawinglayer/inc/texture/texture3d.hxx b/drawinglayer/inc/texture/texture3d.hxx
index 07f4b181b2..1ec4df7073 100644
--- a/drawinglayer/inc/texture/texture3d.hxx
+++ b/drawinglayer/inc/texture/texture3d.hxx
@@ -66,7 +66,7 @@ namespace drawinglayer::texture
// helpers
bool impIsValid(const basegfx::B2DPoint& rUV, sal_Int32& rX, sal_Int32& rY) const;
- sal_uInt8 impGetTransparence(sal_Int32 rX, sal_Int32 rY) const;
+ sal_uInt8 impGetAlpha(sal_Int32 rX, sal_Int32 rY) const;
public:
GeoTexSvxBitmapEx(
diff --git a/drawinglayer/source/texture/texture3d.cxx b/drawinglayer/source/texture/texture3d.cxx
index 3ee751cbbd..4cbcab9d1c 100644
--- a/drawinglayer/source/texture/texture3d.cxx
+++ b/drawinglayer/source/texture/texture3d.cxx
@@ -103,7 +103,7 @@ namespace drawinglayer::texture
{
}
- sal_uInt8 GeoTexSvxBitmapEx::impGetTransparence(sal_Int32 rX, sal_Int32 rY) const
+ sal_uInt8 GeoTexSvxBitmapEx::impGetAlpha(sal_Int32 rX, sal_Int32 rY) const
{
if(mbIsAlpha)
{
@@ -148,10 +148,10 @@ namespace drawinglayer::texture
if(mbIsAlpha)
{
- // when we have a transparence, make use of it
- const sal_uInt8 aLuminance(impGetTransparence(nX, nY));
+ // when we have alpha, make use of it
+ const sal_uInt8 aAlpha(impGetAlpha(nX, nY));
- rfOpacity = (static_cast<double>(0xff - aLuminance) * (1.0 / 255.0));
+ rfOpacity = (static_cast<double>(aAlpha) * (1.0 / 255.0));
}
else
{
@@ -173,8 +173,8 @@ namespace drawinglayer::texture
if(mbIsAlpha)
{
// this texture has an alpha part, use it
- const sal_uInt8 aLuminance(impGetTransparence(nX, nY));
- const double fNewOpacity(static_cast<double>(0xff - aLuminance) * (1.0 / 255.0));
+ const sal_uInt8 aAlpha(impGetAlpha(nX, nY));
+ const double fNewOpacity(static_cast<double>(aAlpha) * (1.0 / 255.0));
rfOpacity = 1.0 - ((1.0 - fNewOpacity) * (1.0 - rfOpacity));
}